@@ -3,6 +3,7 @@
 from .client import ONVIFClient
 from .operator import ONVIFOperator, CacheMode
 from .utils import ONVIFWSDL, ONVIFOperationException, ONVIFErrorHandler, ZeepPatcher
+from .cli import main as ONVIFCLI
 
 __all__ = [
     "ONVIFClient",
@@ -12,4 +13,5 @@ __all__ = [
     "ONVIFOperationException",
     "ONVIFErrorHandler",
     "ZeepPatcher",
+    "ONVIFCLI",
 ]
